Welcome to cookies_utilities’ documentation! — cookies_utilities 0.0.1 documentation

# Welcome to cookies_utilities’ documentation!

This package is intended to provide useful functions and classes. Please see Documentation.

## Installation

You can install the release version from PyPI.

    pip install cookies_utilities

If you want to use the latest version that has not been released, clone our GitHub repository and install from the local directory.

    git clone https://github.com/CookieBox26/cookies_utilities.git
    cd cookies_utilities
    pip install .

Contents

- Documentation
  - Functions
  - Classes

## Links

- PyPI

- GitHub – If you want to maintain this package, please refer to the README in the GitHub repository.

## Index

- Index